Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1726)

Unified Diff: content/renderer/media/webaudio_capturer_source.h

Issue 37793005: move the APM to chrome. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: added a switch, it uses the APM in WebRtc if the switch is off, otherwise use the APM in Chrome. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/webaudio_capturer_source.h
diff --git a/content/renderer/media/webaudio_capturer_source.h b/content/renderer/media/webaudio_capturer_source.h
index b438a4083ee1d5ff208a8c132bf0ac8346ce0247..3de36ca985c63737836b470deab3df2bfba1f020 100644
--- a/content/renderer/media/webaudio_capturer_source.h
+++ b/content/renderer/media/webaudio_capturer_source.h
@@ -16,8 +16,8 @@
namespace content {
+class WebRtcAudioCapturer;
class WebRtcLocalAudioTrack;
-class WebRtcLocalAudioSourceProvider;
// WebAudioCapturerSource is the missing link between
// WebAudio's MediaStreamAudioDestinationNode and WebRtcLocalAudioTrack.
@@ -44,8 +44,7 @@ class WebAudioCapturerSource
// |track| is the sink of the data flow. |source_provider| is the source of
// the data flow where stream information like delay, volume, key_pressed,
// is stored.
- void Start(WebRtcLocalAudioTrack* track,
- WebRtcLocalAudioSourceProvider* source_provider);
+ void Start(WebRtcLocalAudioTrack* track, WebRtcAudioCapturer* capturer);
// Called when the media audio track is stopping.
void Stop();
@@ -63,10 +62,10 @@ class WebAudioCapturerSource
// To avoid circular reference, a raw pointer is kept here.
WebRtcLocalAudioTrack* track_;
// A raw pointer to the source provider to get audio processing params like
// delay, volume, key_pressed information.
- // This |source_provider_| is guaranteed to outlive this object.
- WebRtcLocalAudioSourceProvider* source_provider_;
+ // This |capturer_| is guaranteed to outlive this object.
+ WebRtcAudioCapturer* capturer_;
media::AudioParameters params_;

Powered by Google App Engine
@@ -63,10 +62,10 @@ class WebAudioCapturerSource
// To avoid circular reference, a raw pointer is kept here.
WebRtcLocalAudioTrack* track_;
- // A raw pointer to the source provider to get audio processing params like
+ // A raw pointer to the capturer to get audio processing params like
// delay, volume, key_pressed information.
This is Rietveld 408576698